@@ -63,7 +63,7 @@ int main(int argc, char *argv[])
     signal(SIGINT, signalHandler);
     signal(SIGTERM, signalHandler);
     signal(SIGHUP, signalHandler);
-    //signal(SIGQUIT, signalHandler); // allow SIGQUIT CTRL-\?
+    // signal(SIGQUIT, signalHandler); // allow SIGQUIT CTRL-\?
 
     QCommandLineParser parser;
     parser.setApplicationDescription(QObject::tr("Tool used for creating a live-CD from the running system"));
@@ -74,23 +74,37 @@ int main(int argc, char *argv[])
 #endif
     parser.addOption({{"d", "directory"}, QObject::tr("Output directory"), QObject::tr("path")});
     parser.addOption({{"f", "file"}, QObject::tr("Output filename"), QObject::tr("name")});
-    parser.addOption({{"k", "kernel"}, QObject::tr("Name a different kernel to use other than the default running kernel, use format returned by 'uname -r'") + " " +
-                      QObject::tr("Or the full path: %1").arg(QStringLiteral("/boot/vmlinuz-x.xx.x...")), QObject::tr("version, or path")});
-    parser.addOption({{"l", "compression-level"}, QObject::tr("Compression level options.") + " "
-                      + QObject::tr("Use quotes: \"-Xcompression-level <level>\", "
-                      "or \"-Xalgorithm <algorithm>\", or \"-Xhc\", see mksquashfs man page"), QObject::tr("\"option\"")});
-    parser.addOption({{"m", "month"}, QObject::tr("Create a monthly snapshot, add 'Month' name in the ISO name, skip used space calculation") + " " +
-                      QObject::tr("This option sets reset-accounts and compression to defaults, arguments changing those items will be ignored")});
+    parser.addOption({{"k", "kernel"},
+                      QObject::tr("Name a different kernel to use other than the default running kernel, use format "
+                                  "returned by 'uname -r'")
+                          + " " + QObject::tr("Or the full path: %1").arg(QStringLiteral("/boot/vmlinuz-x.xx.x...")),
+                      QObject::tr("version, or path")});
+    parser.addOption({{"l", "compression-level"},
+                      QObject::tr("Compression level options.") + " "
+                          + QObject::tr("Use quotes: \"-Xcompression-level <level>\", "
+                                        "or \"-Xalgorithm <algorithm>\", or \"-Xhc\", see mksquashfs man page"),
+                      QObject::tr("\"option\"")});
+    parser.addOption(
+        {{"m", "month"},
+         QObject::tr("Create a monthly snapshot, add 'Month' name in the ISO name, skip used space calculation") + " "
+             + QObject::tr(
+                 "This option sets reset-accounts and compression to defaults, arguments changing those items "
+                 "will be ignored")});
     parser.addOption({{"n", "no-checksums"}, QObject::tr("Don't calculate checksums for resulting ISO file")});
-    parser.addOption({{"p", "preempt"}, QObject::tr("Option to fix issue with calculating checksums on preempt_rt kernels")});
+    parser.addOption(
+        {{"p", "preempt"}, QObject::tr("Option to fix issue with calculating checksums on preempt_rt kernels")});
     parser.addOption({{"r", "reset"}, QObject::tr("Resetting accounts (for distribution to others)")});
     parser.addOption({{"s", "checksums"}, QObject::tr("Calculate checksums for resulting ISO file")});
-    parser.addOption({{"o", "override-size"}, QObject::tr("Skip calculating free space to see if the resulting ISO will fit")});
-    parser.addOption({{"x", "exclude"}, QObject::tr("Exclude main folders, valid choices: ")
-                      + "Desktop, Documents, Downloads, Music, Networks, Pictures, Steam, Videos, VirtualBox. " +
-                      QObject::tr("Use the option one time for each item you want to exclude"), QObject::tr("one item")});
-    parser.addOption({{"z", "compression"}, QObject::tr("Compression format, valid choices: ")
-                      + "lz4, lzo, gzip, xz, zstd", QObject::tr("format")});
+    parser.addOption(
+        {{"o", "override-size"}, QObject::tr("Skip calculating free space to see if the resulting ISO will fit")});
+    parser.addOption({{"x", "exclude"},
+                      QObject::tr("Exclude main folders, valid choices: ")
+                          + "Desktop, Documents, Downloads, Music, Networks, Pictures, Steam, Videos, VirtualBox. "
+                          + QObject::tr("Use the option one time for each item you want to exclude"),
+                      QObject::tr("one item")});
+    parser.addOption({{"z", "compression"},
+                      QObject::tr("Compression format, valid choices: ") + "lz4, lzo, gzip, xz, zstd",
+                      QObject::tr("format")});
     parser.addOption({QStringLiteral("shutdown"), QObject::tr("Shutdown computer when done.")});
 
     QStringList opts;
@@ -110,7 +124,8 @@ int main(int argc, char *argv[])
 #ifdef CLI_BUILD
     // root guard
     if (QProcess::execute("/bin/bash", {"-c", "logname |grep -q ^root$"}) == 0) {
-        qDebug() << QObject::tr("You seem to be logged in as root, please log out and log in as normal user to use this program.");
+        qDebug() << QObject::tr(
+            "You seem to be logged in as root, please log out and log in as normal user to use this program.");
         exit(EXIT_FAILURE);
     }
     QCoreApplication app(argc, argv);
@@ -119,57 +134,63 @@ int main(int argc, char *argv[])
         QCoreApplication app(argc, argv);
         // root guard
         if (QProcess::execute(QStringLiteral("/bin/bash"), {"-c", "logname |grep -q ^root$"}) == 0) {
-            qDebug() << QObject::tr("You seem to be logged in as root, please log out and log in as normal user to use this program.");
+            qDebug() << QObject::tr(
+                "You seem to be logged in as root, please log out and log in as normal user to use this program.");
             exit(EXIT_FAILURE);
         }
 #endif
-        QCoreApplication::setApplicationVersion(VERSION);
-        parser.process(app);
-        setTranslation();
-        checkSquashfs();
-        if (getuid() == 0) {
-            qputenv("HOME", "/root");
-            setLog();
-            qDebug().noquote() << qApp->applicationName() << QObject::tr("version:") << qApp->applicationVersion();
-            if (argc > 1) qDebug().noquote() << "Args:" << qApp->arguments();
-            Batchprocessing batch(parser);
-            QTimer::singleShot(0, &app, &QCoreApplication::quit);
-            return QCoreApplication::exec();
-        } else {
-            qDebug().noquote() << QObject::tr("You must run this program as root.");
-            return EXIT_FAILURE;
-        }
-#ifndef CLI_BUILD
+    QCoreApplication::setApplicationVersion(VERSION);
+    parser.process(app);
+    setTranslation();
+    checkSquashfs();
+    if (getuid() == 0) {
+        qputenv("HOME", "/root");
+        setLog();
+        qDebug().noquote() << qApp->applicationName() << QObject::tr("version:") << qApp->applicationVersion();
+        if (argc > 1)
+            qDebug().noquote() << "Args:" << qApp->arguments();
+        Batchprocessing batch(parser);
+        QTimer::singleShot(0, &app, &QCoreApplication::quit);
+        return QCoreApplication::exec();
     } else {
-        QApplication app(argc, argv);
-        QApplication::setApplicationVersion(VERSION);
-        parser.process(app);
-        setTranslation();
-        checkSquashfs();
-
-        // root guard
-        if (QProcess::execute(QStringLiteral("/bin/bash"), {"-c", "logname |grep -q ^root$"}) == 0) {
-            QMessageBox::critical(nullptr, QObject::tr("Error"),
-                                  QObject::tr("You seem to be logged in as root, please log out and log in as normal user to use this program."));
-            exit(EXIT_FAILURE);
-        }
-
-        if (getuid() == 0) {
-            qputenv("HOME", "/root");
-            setLog();
-            qDebug().noquote() << qApp->applicationName() << QObject::tr("version:") << qApp->applicationVersion();
-            if (argc > 1) qDebug().noquote() << "Args:" << qApp->arguments();
-            MainWindow w(nullptr, parser);
-            w.show();
-            exit(QApplication::exec());
-        } else {
-            QProcess::startDetached(QStringLiteral("/usr/bin/mx-snapshot-launcher"), {});
-        }
+        qDebug().noquote() << QObject::tr("You must run this program as root.");
+        return EXIT_FAILURE;
     }
+#ifndef CLI_BUILD
+}
+else
+{
+    QApplication app(argc, argv);
+    QApplication::setApplicationVersion(VERSION);
+    parser.process(app);
+    setTranslation();
+    checkSquashfs();
+
+    // root guard
+    if (QProcess::execute(QStringLiteral("/bin/bash"), {"-c", "logname |grep -q ^root$"}) == 0) {
+        QMessageBox::critical(
+            nullptr, QObject::tr("Error"),
+            QObject::tr(
+                "You seem to be logged in as root, please log out and log in as normal user to use this program."));
+        exit(EXIT_FAILURE);
+    }
+
+    if (getuid() == 0) {
+        qputenv("HOME", "/root");
+        setLog();
+        qDebug().noquote() << qApp->applicationName() << QObject::tr("version:") << qApp->applicationVersion();
+        if (argc > 1)
+            qDebug().noquote() << "Args:" << qApp->arguments();
+        MainWindow w(nullptr, parser);
+        w.show();
+        exit(QApplication::exec());
+    } else {
+        QProcess::startDetached(QStringLiteral("/usr/bin/mx-snapshot-launcher"), {});
+    }
+}
 #endif
 }
 
-
 // The implementation of the handler
 void messageHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg)
 {
@@ -180,26 +201,37 @@ void messageHandler(QtMsgType type, const QMessageLogContext &context, const QSt
         return;
     QTextStream out(&logFile);
     out << QDateTime::currentDateTime().toString(QStringLiteral("yyyy-MM-dd hh:mm:ss.zzz "));
-    switch (type)
-    {
-    case QtInfoMsg:     out << QStringLiteral("INF "); break;
-    case QtDebugMsg:    out << QStringLiteral("DBG "); break;
-    case QtWarningMsg:  out << QStringLiteral("WRN "); break;
-    case QtCriticalMsg: out << QStringLiteral("CRT "); break;
-    case QtFatalMsg:    out << QStringLiteral("FTL "); break;
+    switch (type) {
+    case QtInfoMsg:
+        out << QStringLiteral("INF ");
+        break;
+    case QtDebugMsg:
+        out << QStringLiteral("DBG ");
+        break;
+    case QtWarningMsg:
+        out << QStringLiteral("WRN ");
+        break;
+    case QtCriticalMsg:
+        out << QStringLiteral("CRT ");
+        break;
+    case QtFatalMsg:
+        out << QStringLiteral("FTL ");
+        break;
     }
     out << context.category << QStringLiteral(": ") << msg << "\n";
 }
 
 void setTranslation()
 {
-    if (qtTran.load(QLocale(), QStringLiteral("qt"), QStringLiteral("_"), QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
+    if (qtTran.load(QLocale(), QStringLiteral("qt"), QStringLiteral("_"),
+                    QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
         qApp->installTranslator(&qtTran);
 
     if (qtBaseTran.load("qtbase_" + QLocale().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
         qApp->installTranslator(&qtBaseTran);
 
-    if (appTran.load(qApp->applicationName() + "_" + QLocale().name(), "/usr/share/" + qApp->applicationName() + "/locale"))
+    if (appTran.load(qApp->applicationName() + "_" + QLocale().name(),
+                     "/usr/share/" + qApp->applicationName() + "/locale"))
         qApp->installTranslator(&appTran);
 }
 
@@ -212,15 +244,16 @@ void checkSquashfs()
     current_kernel = proc.readAllStandardOutput().trimmed();
 
     if (QFile::exists("/boot/config-" + current_kernel)
-            && QProcess::execute(QStringLiteral("grep"), {"-q", "^CONFIG_SQUASHFS=[ym]", "/boot/config-" + current_kernel}) != 0) {
+        && QProcess::execute(QStringLiteral("grep"), {"-q", "^CONFIG_SQUASHFS=[ym]", "/boot/config-" + current_kernel})
+               != 0) {
 #ifdef CLI_BUILD
         qDebug() << QObject::tr("Current kernel doesn't support Squashfs, cannot continue.");
 #else
-        QString message = QObject::tr("Current kernel doesn't support Squashfs, cannot continue.");
-        if (qApp->metaObject()->className() !=  QLatin1String("QApplication"))
-            qDebug() << message;
-        else
-            QMessageBox::critical(nullptr, QObject::tr("Error"), message);
+            QString message = QObject::tr("Current kernel doesn't support Squashfs, cannot continue.");
+            if (qApp->metaObject()->className() != QLatin1String("QApplication"))
+                qDebug() << message;
+            else
+                QMessageBox::critical(nullptr, QObject::tr("Error"), message);
 #endif
         exit(EXIT_FAILURE);
     }
@@ -240,12 +273,19 @@ void setLog()
 
 void signalHandler(int signal)
 {
-    switch (signal)
-    {
-    case SIGHUP:  qDebug() << "\nSIGHUP"; break;
-    case SIGINT:  qDebug() << "\nSIGINT"; break;
-    case SIGQUIT: qDebug() << "\nSIGQUIT"; break;
-    case SIGTERM: qDebug() << "\nSIGTERM"; break;
+    switch (signal) {
+    case SIGHUP:
+        qDebug() << "\nSIGHUP";
+        break;
+    case SIGINT:
+        qDebug() << "\nSIGINT";
+        break;
+    case SIGQUIT:
+        qDebug() << "\nSIGQUIT";
+        break;
+    case SIGTERM:
+        qDebug() << "\nSIGTERM";
+        break;
     }
     qApp->quit(); // quit app anyway in case a subprocess was killed, but at least this calls aboutToQuit
 }
